@@ -1,5 +1,5 @@
 REDIRECT_STATUS_CODES = {301, 302, 303, 307, 308}
-RESERVED_KWARGS = {"state", "headers", "cookies", "request", "socket", "data", "query"}
+RESERVED_KWARGS = {"state", "headers", "cookies", "request", "socket", "data", "query", "scope"}
 EXTRA_KEY_REQUIRED = "required"
 EXTRA_KEY_VALUE_TYPE = "value_type"
 EXTRA_KEY_IS_PARAMETER = "is_parameter"
