@@ -12,12 +12,13 @@ from typing import (
 )
 
 from orjson import OPT_SERIALIZE_NUMPY, dumps, loads
-from pydantic import BaseConfig, BaseModel
+from pydantic import BaseConfig, BaseModel, validator
 from typing_extensions import Literal
 
 from starlite.config.logging import BaseLoggingConfig, LoggingConfig
 from starlite.exceptions import MissingDependencyException
-from starlite.utils import default_serializer
+from starlite.types import BeforeMessageSendHookHandler
+from starlite.utils import AsyncCallable, default_serializer
 
 try:
     from sqlalchemy import create_engine
@@ -61,6 +62,26 @@ def serializer(value: Any) -> str:
     ).decode("utf-8")
 
 
+async def default_before_send_handler(message: "Message", _: "State", scope: "Scope") -> None:
+    """
+    Handles closing and cleaning up sessions before sending.
+    Args:
+        message:
+        _:
+        scope:
+
+    Returns:
+
+    """
+    session = cast("Optional[Union[Session, AsyncSession]]", scope.get(SESSION_SCOPE_KEY))
+    if session and message["type"] in SESSION_TERMINUS_ASGI_EVENTS:
+        if isinstance(session, AsyncSession):
+            await session.close()
+        else:
+            session.close()
+        del scope[SESSION_SCOPE_KEY]  # type: ignore
+
+
 class SQLAlchemySessionConfig(BaseModel):
     class Config(BaseConfig):
         arbitrary_types_allowed = True
@@ -179,14 +200,41 @@ class SQLAlchemyConfig(BaseModel):
     Configuration options for the 'sessionmaker'. The configuration options are documented in the
         SQLAlchemy documentation.
     """
-    session_maker: Type[sessionmaker] = sessionmaker
+    session_maker_class: Type[sessionmaker] = sessionmaker
     """
     Sessionmaker class to use.
     """
-    session_maker_app_state_key: str = "session_maker"
+    session_maker_app_state_key: str = "session_maker_class"
     """
     Key under which to store the SQLAlchemy 'sessionmaker' in the application [State][starlite.datastructures.State] instance.
     """
+    session_maker_instance: Optional[sessionmaker] = None
+    """
+    Optional sessionmaker to use. If set, the plugin will use the provided instance rather than instantiate a sessionmaker.
+    """
+    engine_instance: Optional[Union[Engine, FutureEngine, AsyncEngine]] = None
+    """
+    Optional engine to use. If set, the plugin will use the provided instance rather than instantiate an engine.
+    """
+    before_send_handler: BeforeMessageSendHookHandler = default_before_send_handler
+    """
+    Handler to call before the ASGI message is sent. The handler should handle closing the session stored in the ASGI
+    scope, if its still open, and committing and uncommitted data.
+    """
+
+    @validator("before_send_handler", always=True)
+    def validate_before_send_handler(  # pylint: disable=no-self-argument
+        cls, value: BeforeMessageSendHookHandler
+    ) -> Any:
+        """
+
+        Args:
+            value: A before send handler callable.
+
+        Returns:
+            The handler wrapped in AsyncCallable.
+        """
+        return AsyncCallable(value)  # type: ignore[arg-type]
 
     @property
     def engine_config_dict(self) -> Dict[str, Any]:
@@ -202,6 +250,37 @@ class SQLAlchemyConfig(BaseModel):
 
         return self.engine_config.dict(exclude_none=True, exclude=engine_excluded_fields)
 
+    @property
+    def engine(self) -> Union["Engine", "FutureEngine", "AsyncEngine"]:
+        """
+
+        Returns:
+            Getter that returns the engine instance used by the plugin.
+        """
+        if not self.engine_instance:
+            create_engine_callable = (
+                self.create_async_engine_callable if self.use_async_engine else self.create_engine_callable
+            )
+            self.engine_instance = create_engine_callable(self.connection_string, **self.engine_config_dict)
+        return cast("Union[Engine, FutureEngine, AsyncEngine]", self.engine_instance)
+
+    @property
+    def session_maker(self) -> sessionmaker:
+        """
+
+        Returns:
+            Getter that returns the session_maker instance used by the plugin.
+        """
+        if not self.session_maker_instance:
+            session_maker_kwargs = self.session_config.dict(
+                exclude_none=True, exclude={"future"} if self.use_async_engine else set()
+            )
+            session_class = self.session_class or (AsyncSession if self.use_async_engine else Session)
+            self.session_maker_instance = self.session_maker_class(
+                self.engine, class_=session_class, **session_maker_kwargs
+            )
+        return cast("sessionmaker", self.session_maker_instance)
+
     def create_db_session_dependency(self, state: "State", scope: "Scope") -> Union[Session, AsyncSession]:
         """
 
@@ -227,19 +306,9 @@ class SQLAlchemyConfig(BaseModel):
         Returns:
             None
         """
-        create_engine_callable = (
-            self.create_async_engine_callable if self.use_async_engine else self.create_engine_callable
-        )
-        session_maker_kwargs = self.session_config.dict(
-            exclude_none=True, exclude={"future"} if self.use_async_engine else set()
-        )
-        session_class = self.session_class or (AsyncSession if self.use_async_engine else Session)
-        engine = state[self.engine_app_state_key] = create_engine_callable(
-            self.connection_string, **self.engine_config_dict
-        )
-        state[self.session_maker_app_state_key] = self.session_maker(
-            engine, class_=session_class, **session_maker_kwargs
-        )
+
+        state[self.engine_app_state_key] = self.engine
+        state[self.session_maker_app_state_key] = self.session_maker
 
     async def on_shutdown(self, state: "State") -> None:
         """Disposes of the SQLAlchemy engine.
@@ -257,26 +326,6 @@ class SQLAlchemyConfig(BaseModel):
             engine.dispose()
         del state[self.engine_app_state_key]
 
-    @staticmethod
-    async def before_send_handler(message: "Message", _: "State", scope: "Scope") -> None:
-        """
-        Handles closing and cleaning up sessions before sending.
-        Args:
-            message:
-            _:
-            scope:
-
-        Returns:
-
-        """
-        session = cast("Optional[Union[Session, AsyncSession]]", scope.get(SESSION_SCOPE_KEY))
-        if session and message["type"] in SESSION_TERMINUS_ASGI_EVENTS:
-            if isinstance(session, AsyncSession):
-                await session.close()
-            else:
-                session.close()
-            del scope[SESSION_SCOPE_KEY]  # type: ignore
-
     def config_sql_alchemy_logging(self, logging_config: Optional[BaseLoggingConfig]) -> None:
         """Adds the SQLAlchemy loggers to the logging config. Currently working
         only with [LoggingConfig][starlite.config.logging.LoggingConfig].
