@@ -190,23 +190,6 @@ class Router:
                 route_map[route.path] = cast("WebSocketRoute", route).route_handler
         return route_map
 
-    @property
-    def route_handler_method_view(
-        self,
-    ) -> Dict[str, List[str]]:
-        """
-        Returns:
-             A dictionary mapping route handlers to paths
-        """
-        route_map: Dict[str, List[str]] = collections.defaultdict(list)
-        for route in self.routes:
-            if isinstance(route, HTTPRoute):
-                for route_handler in route.route_handlers:
-                    route_map[route_handler.fn.__qualname__].append(route.path)  # type: ignore
-            else:
-                route_map[cast("WebSocketRoute", route).route_handler.fn.__qualname__].append(route.path)  # type: ignore
-        return route_map
-
     @classmethod
     def _map_route_handlers(
         cls,
